@@ -7,7 +7,7 @@
 #' "date", "publisher", "author", "title".  
 #' @examples \dontrun{
 #' meta <- metadata()
-#' meta[publisher %in% c("Nature", "Science") & ntaxa > 100 & kind == "Species Tree",]
+#' meta[publisher %in% c("Nature", "Science") & ntaxa > 50 & kind == "Species Tree",]
 #' }
 #' @import reshape2 data.table
 #' @export
@@ -35,13 +35,7 @@ metadata <- function(phylo.md = NULL, oai.md=NULL){
     author = oai_metadata("author", oai.md),
     title = oai_metadata("title", oai.md),
     Study.id = oai_metadata("Study.id", oai.md))
-
-  oai <- data.table(oai)
-  setkey(oai, "Study.id")
-  phylo <- data.table(phylo)
-  setkey(phylo, "Study.id")
-  
-  both <-  phylo[oai] # Fast join
+  both <- merge(phylo, oai)
   class(both$ntaxa) <- "numeric"
   both
 }
@@ -57,19 +51,19 @@ metadata <- function(phylo.md = NULL, oai.md=NULL){
 #' @param ... additional arguments to \code{search_treebase}
 #' @return a list of the values matching the query
 #' @keywords internal
-#' @examples
-#' \dontrun{
-#'      # calls will work without a metadata object, but require longer to download data
-#'      kind <- treebase:::phylo_metadata("kind")
-#'      type <- phylo_metadata("type") 
-#'      table(kind, type)
-#'      }
-#'      # but are much faster if the data object is provided, see cache_treebase():
-#'      data(treebase)
-#'      kind <- treebase:::phylo_metadata("kind", metadata=treebase)
-#'      type <- treebase:::phylo_metadata("type", metadata=treebase) 
-#'      table(kind, type)
-#' 
+# @examples
+# \dontrun{
+#      # calls will work without a metadata object, but requires longer to download data
+#      kind <- phylo_metadata("kind")
+#      type <- phylo_metadata("type") 
+#      table(kind, type)
+#      }
+#      # but are much faster if the data object is provided, see cache_treebase():
+#      data(treebase)
+#      kind <- phylo_metadata("kind", metadata=treebase)
+#      type <- phylo_metadata("type", metadata=treebase) 
+#      table(kind, type)
+# 
 phylo_metadata <- function(x =  c("Study.id", "Tree.id", "kind", "type", "quality", "ntaxa"), metadata=NULL, ...){
   x = match.arg(x)
 # Aliases
@@ -91,18 +85,18 @@ phylo_metadata <- function(x =  c("Study.id", "Tree.id", "kind", "type", "qualit
 #' @param ... additional arguments to \code{download_metadata}
 #' @return a list of values matching the query
 #' @keywords internal
-#' @examples
-#' \dontrun{
-#'     # automatically search each time (note: this calls internal function now)
-#'     dates <- treebase:::oai_metadata("date") 
-#'     pub <- treebase:::oai_metadata("publisher")
-#'     table(dates, pub)
-#' }
-#'    # Using cached data from an earlier download
-#'     data(metadata) 
-#'     dates <- treebase:::oai_metadata("date", metadata=metadata) 
-#'     pub <- treebase:::oai_metadata("publisher", metadata=metadata)
-#'     table(dates, pub)
+# @examples
+# \dontrun{
+#     # automatically search each time (note: this calls internal function now)
+#     dates <- oai_metadata("date") 
+#     pub <- oai_metadata("publisher")
+#     table(dates, pub)
+# }
+#    # Using cached data from an earlier download
+#     data(metadata) 
+#     dates <- oai_metadata("date", metadata=metadata) 
+#     pub <- oai_metadata("publisher", metadata=metadata)
+#     table(dates, pub)
 oai_metadata <- function(x = c("date", "publisher", "author", "title", "Study.id", "attributes"), metadata=NULL, ...){
   x = match.arg(x)
 # Aliases
